"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validateOpts = exports.getOpts = void 0;

var _fs = require("fs");

var _path = require("path");

var _lodash = require("lodash");

const getOpts = (opts, ctx) => {
  return (0, _lodash.merge)({
    cwd: ctx.cwd
  }, opts);
};

exports.getOpts = getOpts;

const validateOpts = async (opts, ctx) => {
  const {
    cwd,
    runtimeHelpers,
    corejs,
    target,
    noEmit,
    watch
  } = opts;
  const pkg = ctx.project;

  if (runtimeHelpers) {
    if (!corejs) {
      var _pkg$dependencies;

      if (!((_pkg$dependencies = pkg.dependencies) === null || _pkg$dependencies === void 0 ? void 0 : _pkg$dependencies["@babel/runtime"])) {
        ctx.console.warn(`Use @babel/plugin-transform-runtime but @babel/runtime is not installed. Installing it${typeof runtimeHelpers === "string" ? ` with version ${runtimeHelpers}` : ""}...`);
        await ctx.mod.install(`@babel/runtime${typeof runtimeHelpers === "string" ? `@${runtimeHelpers}` : ""}`);
      }
    } else if (corejs === 2 || corejs.version === 2) {
      var _pkg$dependencies2;

      if (!((_pkg$dependencies2 = pkg.dependencies) === null || _pkg$dependencies2 === void 0 ? void 0 : _pkg$dependencies2["@babel/runtime-corejs2"])) {
        ctx.console.warn(`Use @babel/plugin-transform-runtime and enable its corejs option with version 2, but @babel/runtime-corejs2 is not installed. Installing it${typeof runtimeHelpers === "string" ? ` with version ${runtimeHelpers}` : ""}...`);
        await ctx.mod.install(`@babel/runtime-corejs2${typeof runtimeHelpers === "string" ? `@${runtimeHelpers}` : ""}`);
      }
    } else if (corejs === 3 || corejs.version === 3) {
      var _pkg$dependencies3;

      if (!((_pkg$dependencies3 = pkg.dependencies) === null || _pkg$dependencies3 === void 0 ? void 0 : _pkg$dependencies3["@babel/runtime-corejs3"])) {
        ctx.console.warn(`Use @babel/plugin-transform-runtime and enable its corejs option with version 3, but @babel/runtime-corejs3 is not installed. Installing it${typeof runtimeHelpers === "string" ? ` with version ${runtimeHelpers}` : ""}...`);
        await ctx.mod.install(`@babel/runtime-corejs3${typeof runtimeHelpers === "string" ? `@${runtimeHelpers}` : ""}`);
      }
    }
  }

  if (target === "browser") {
    if (!(0, _fs.existsSync)((0, _path.join)(cwd, ".browserslistrc"))) {
      ctx.console.warn("No .browserslistrc found for browser target. Using default...");
      await ctx.utils.writeFile((0, _path.join)(cwd, ".browserslistrc"), await ctx.utils.readFile((0, _path.join)(__dirname, "../template/browserslistrc")));
    }
  }

  if (noEmit) {
    if (watch) {
      ctx.console.warn("Watch mode would not start with noEmit.");
    }
  }
};

exports.validateOpts = validateOpts;